@@ -1,5 +1,5 @@
 package Image::PNG::Const;
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -147,7 +147,6 @@ PNG_FREE_ROWS
 PNG_FREE_PCAL
 PNG_FREE_SCAL
 PNG_FREE_UNKN
-PNG_FREE_LIST
 PNG_FREE_PLTE
 PNG_FREE_TRNS
 PNG_FREE_TEXT
@@ -167,7 +166,39 @@ PNG_IO_CHUNK_CRC
 PNG_IO_MASK_OP
 PNG_IO_MASK_LOC
 PNG_INTERLACE_ADAM7_PASSES
+PNG_IMAGE_VERSION
+PNG_IMAGE_WARNING
+PNG_IMAGE_ERROR
+PNG_FORMAT_FLAG_ALPHA
+PNG_FORMAT_FLAG_COLOR
+PNG_FORMAT_FLAG_LINEAR
+PNG_FORMAT_FLAG_COLORMAP
+PNG_FORMAT_FLAG_BGR
+PNG_FORMAT_FLAG_AFIRST
+PNG_FORMAT_GRAY
+PNG_FORMAT_GA
+PNG_FORMAT_AG
+PNG_FORMAT_RGB
+PNG_FORMAT_BGR
+PNG_FORMAT_RGBA
+PNG_FORMAT_ARGB
+PNG_FORMAT_BGRA
+PNG_FORMAT_ABGR
+PNG_FORMAT_LINEAR_Y
+PNG_FORMAT_LINEAR_Y_ALPHA
+PNG_FORMAT_LINEAR_RGB
+PNG_FORMAT_RGB_COLORMAP
+PNG_FORMAT_BGR_COLORMAP
+PNG_FORMAT_RGBA_COLORMAP
+PNG_FORMAT_ARGB_COLORMAP
+PNG_FORMAT_BGRA_COLORMAP
+PNG_FORMAT_ABGR_COLORMAP
+PNG_IMAGE_FLAG_COLORSPACE_NOT_sRGB
+PNG_IMAGE_FLAG_FAST
+PNG_IMAGE_FLAG_16BIT_sRGB
 PNG_ARM_NEON
+PNG_MAXIMUM_INFLATE_WINDOW
+PNG_SKIP_sRGB_CHECK_PROFILE
 PNG_OPTION_NEXT
 PNG_OPTION_UNSET
 PNG_OPTION_INVALID
@@ -329,7 +360,6 @@ use constant {
     PNG_FREE_PCAL => 0x0080,
     PNG_FREE_SCAL => 0x0100,
     PNG_FREE_UNKN => 0x0200,
-    PNG_FREE_LIST => 0x0400,
     PNG_FREE_PLTE => 0x1000,
     PNG_FREE_TRNS => 0x2000,
     PNG_FREE_TEXT => 0x4000,
@@ -349,8 +379,40 @@ use constant {
     PNG_IO_MASK_OP => 0x000f,
     PNG_IO_MASK_LOC => 0x00f0,
     PNG_INTERLACE_ADAM7_PASSES => 7,
+    PNG_IMAGE_VERSION => 1,
+    PNG_IMAGE_WARNING => 1,
+    PNG_IMAGE_ERROR => 2,
+    PNG_FORMAT_FLAG_ALPHA => 0x01,
+    PNG_FORMAT_FLAG_COLOR => 0x02,
+    PNG_FORMAT_FLAG_LINEAR => 0x04,
+    PNG_FORMAT_FLAG_COLORMAP => 0x08,
+    PNG_FORMAT_FLAG_BGR => 0x10,
+    PNG_FORMAT_FLAG_AFIRST => 0x20,
+    PNG_FORMAT_GRAY => 0,
+    PNG_FORMAT_GA => 0x01,
+    PNG_FORMAT_AG => (0x01|0x20),
+    PNG_FORMAT_RGB => 0x02,
+    PNG_FORMAT_BGR => (0x02|0x10),
+    PNG_FORMAT_RGBA => (0x02|0x01),
+    PNG_FORMAT_ARGB => ((0x02|0x01)|0x20),
+    PNG_FORMAT_BGRA => ((0x02|0x10)|0x01),
+    PNG_FORMAT_ABGR => (((0x02|0x10)|0x01)|0x20),
+    PNG_FORMAT_LINEAR_Y => 0x04,
+    PNG_FORMAT_LINEAR_Y_ALPHA => (0x04|0x01),
+    PNG_FORMAT_LINEAR_RGB => (0x04|0x02),
+    PNG_FORMAT_RGB_COLORMAP => (0x02|0x08),
+    PNG_FORMAT_BGR_COLORMAP => ((0x02|0x10)|0x08),
+    PNG_FORMAT_RGBA_COLORMAP => ((0x02|0x01)|0x08),
+    PNG_FORMAT_ARGB_COLORMAP => (((0x02|0x01)|0x20)|0x08),
+    PNG_FORMAT_BGRA_COLORMAP => (((0x02|0x10)|0x01)|0x08),
+    PNG_FORMAT_ABGR_COLORMAP => ((((0x02|0x10)|0x01)|0x20)|0x08),
+    PNG_IMAGE_FLAG_COLORSPACE_NOT_sRGB => 0x01,
+    PNG_IMAGE_FLAG_FAST => 0x02,
+    PNG_IMAGE_FLAG_16BIT_sRGB => 0x04,
     PNG_ARM_NEON => 0,
-    PNG_OPTION_NEXT => 2,
+    PNG_MAXIMUM_INFLATE_WINDOW => 2,
+    PNG_SKIP_sRGB_CHECK_PROFILE => 4,
+    PNG_OPTION_NEXT => 6,
     PNG_OPTION_UNSET => 0,
     PNG_OPTION_INVALID => 1,
     PNG_OPTION_OFF => 2,
@@ -951,10 +1013,6 @@ PNG_FREE_SCAL has value 0x0100.
 
 PNG_FREE_UNKN has value 0x0200.
 
-=item PNG_FREE_LIST
-
-PNG_FREE_LIST has value 0x0400.
-
 =item PNG_FREE_PLTE
 
 PNG_FREE_PLTE has value 0x1000.
@@ -1031,13 +1089,141 @@ PNG_IO_MASK_LOC has value 0x00f0.
 
 PNG_INTERLACE_ADAM7_PASSES has value 7.
 
+=item PNG_IMAGE_VERSION
+
+PNG_IMAGE_VERSION has value 1.
+
+=item PNG_IMAGE_WARNING
+
+PNG_IMAGE_WARNING has value 1.
+
+=item PNG_IMAGE_ERROR
+
+PNG_IMAGE_ERROR has value 2.
+
+=item PNG_FORMAT_FLAG_ALPHA
+
+PNG_FORMAT_FLAG_ALPHA has value 0x01.
+
+=item PNG_FORMAT_FLAG_COLOR
+
+PNG_FORMAT_FLAG_COLOR has value 0x02.
+
+=item PNG_FORMAT_FLAG_LINEAR
+
+PNG_FORMAT_FLAG_LINEAR has value 0x04.
+
+=item PNG_FORMAT_FLAG_COLORMAP
+
+PNG_FORMAT_FLAG_COLORMAP has value 0x08.
+
+=item PNG_FORMAT_FLAG_BGR
+
+PNG_FORMAT_FLAG_BGR has value 0x10.
+
+=item PNG_FORMAT_FLAG_AFIRST
+
+PNG_FORMAT_FLAG_AFIRST has value 0x20.
+
+=item PNG_FORMAT_GRAY
+
+PNG_FORMAT_GRAY has value 0.
+
+=item PNG_FORMAT_GA
+
+PNG_FORMAT_GA has value 0x01.
+
+=item PNG_FORMAT_AG
+
+PNG_FORMAT_AG has value (0x01|0x20).
+
+=item PNG_FORMAT_RGB
+
+PNG_FORMAT_RGB has value 0x02.
+
+=item PNG_FORMAT_BGR
+
+PNG_FORMAT_BGR has value (0x02|0x10).
+
+=item PNG_FORMAT_RGBA
+
+PNG_FORMAT_RGBA has value (0x02|0x01).
+
+=item PNG_FORMAT_ARGB
+
+PNG_FORMAT_ARGB has value ((0x02|0x01)|0x20).
+
+=item PNG_FORMAT_BGRA
+
+PNG_FORMAT_BGRA has value ((0x02|0x10)|0x01).
+
+=item PNG_FORMAT_ABGR
+
+PNG_FORMAT_ABGR has value (((0x02|0x10)|0x01)|0x20).
+
+=item PNG_FORMAT_LINEAR_Y
+
+PNG_FORMAT_LINEAR_Y has value 0x04.
+
+=item PNG_FORMAT_LINEAR_Y_ALPHA
+
+PNG_FORMAT_LINEAR_Y_ALPHA has value (0x04|0x01).
+
+=item PNG_FORMAT_LINEAR_RGB
+
+PNG_FORMAT_LINEAR_RGB has value (0x04|0x02).
+
+=item PNG_FORMAT_RGB_COLORMAP
+
+PNG_FORMAT_RGB_COLORMAP has value (0x02|0x08).
+
+=item PNG_FORMAT_BGR_COLORMAP
+
+PNG_FORMAT_BGR_COLORMAP has value ((0x02|0x10)|0x08).
+
+=item PNG_FORMAT_RGBA_COLORMAP
+
+PNG_FORMAT_RGBA_COLORMAP has value ((0x02|0x01)|0x08).
+
+=item PNG_FORMAT_ARGB_COLORMAP
+
+PNG_FORMAT_ARGB_COLORMAP has value (((0x02|0x01)|0x20)|0x08).
+
+=item PNG_FORMAT_BGRA_COLORMAP
+
+PNG_FORMAT_BGRA_COLORMAP has value (((0x02|0x10)|0x01)|0x08).
+
+=item PNG_FORMAT_ABGR_COLORMAP
+
+PNG_FORMAT_ABGR_COLORMAP has value ((((0x02|0x10)|0x01)|0x20)|0x08).
+
+=item PNG_IMAGE_FLAG_COLORSPACE_NOT_sRGB
+
+PNG_IMAGE_FLAG_COLORSPACE_NOT_sRGB has value 0x01.
+
+=item PNG_IMAGE_FLAG_FAST
+
+PNG_IMAGE_FLAG_FAST has value 0x02.
+
+=item PNG_IMAGE_FLAG_16BIT_sRGB
+
+PNG_IMAGE_FLAG_16BIT_sRGB has value 0x04.
+
 =item PNG_ARM_NEON
 
 PNG_ARM_NEON has value 0.
 
+=item PNG_MAXIMUM_INFLATE_WINDOW
+
+PNG_MAXIMUM_INFLATE_WINDOW has value 2.
+
+=item PNG_SKIP_sRGB_CHECK_PROFILE
+
+PNG_SKIP_sRGB_CHECK_PROFILE has value 4.
+
 =item PNG_OPTION_NEXT
 
-PNG_OPTION_NEXT has value 2.
+PNG_OPTION_NEXT has value 6.
 
 =item PNG_OPTION_UNSET
 
@@ -1076,7 +1262,7 @@ Ben Bullock, <bkb@cpan.org>
 =head1 COPYRIGHT & LICENCE
 
 The Image::PNG::Libpng package and associated files are copyright (C)
-2014 Ben Bullock.
+2015 Ben Bullock.
 
 You can use, copy, modify and redistribute Image::PNG::Libpng and
 associated files under the Perl Artistic Licence or the GNU General
